Do single loop compound search for all speeds. About 7% speed-up with 0.7-0.1% loss. STATS_CHANGED Change-Id: I0f1b7148c0f20d40a0b3e88144392825352c3046
diff --git a/av1/encoder/speed_features.c b/av1/encoder/speed_features.c index 99e9c62..cad140c 100644 --- a/av1/encoder/speed_features.c +++ b/av1/encoder/speed_features.c
@@ -216,6 +216,7 @@ // TODO(debargha): Test, tweak and turn on either 1 or 2 sf->inter_mode_rd_model_estimation = 1; + sf->two_loop_comp_search = 0; sf->prune_ref_frame_for_rect_partitions = !is_boosted_arf2_bwd_type; sf->prune_ref_mode_for_partitions = sf->prune_ref_frame_for_rect_partitions; @@ -434,6 +435,7 @@ // TODO(debargha): Test, tweak and turn on either 1 or 2 sf->inter_mode_rd_model_estimation = 0; + sf->two_loop_comp_search = 0; sf->prune_ref_frame_for_rect_partitions = !(boosted || cpi->refresh_bwd_ref_frame || cpi->refresh_alt2_ref_frame);